@@ -66,7 +66,7 @@ async def load_resource(path: str, name: str) -> IMG:
     return Image.open(BytesIO(image)).convert('RGBA')
 
 
-async def petpet(img: IMG, *args) -> BytesIO:
+async def petpet(img: IMG) -> BytesIO:
     frames = []
     locs = [(14, 20, 98, 98), (12, 33, 101, 85), (8, 40, 110, 76),
             (10, 33, 102, 84), (12, 20, 98, 98)]
@@ -80,7 +80,7 @@ async def petpet(img: IMG, *args) -> BytesIO:
     return save_gif(frames, 0.06)
 
 
-async def kiss(self_img: IMG, user_img: IMG, *args) -> BytesIO:
+async def kiss(self_img: IMG, user_img: IMG) -> BytesIO:
     user_locs = [(58, 90), (62, 95), (42, 100), (50, 100), (56, 100), (18, 120), (28, 110),
                  (54, 100), (46, 100), (60, 100), (35, 115), (20, 120), (40, 96)]
     self_locs = [(92, 64), (135, 40), (84, 105), (80, 110), (155, 82), (60, 96), (50, 80),
@@ -96,7 +96,7 @@ async def kiss(self_img: IMG, user_img: IMG, *args) -> BytesIO:
     return save_gif(frames, 0.05)
 
 
-async def rub(self_img: IMG, user_img: IMG, *args) -> BytesIO:
+async def rub(self_img: IMG, user_img: IMG) -> BytesIO:
     user_locs = [(39, 91, 75, 75), (49, 101, 75, 75), (67, 98, 75, 75),
                  (55, 86, 75, 75), (61, 109, 75, 75), (65, 101, 75, 75)]
     self_locs = [(102, 95, 70, 80, 0), (108, 60, 50, 100, 0), (97, 18, 65, 95, 0),
@@ -114,7 +114,7 @@ async def rub(self_img: IMG, user_img: IMG, *args) -> BytesIO:
     return save_gif(frames, 0.05)
 
 
-async def play(img: IMG, *args) -> BytesIO:
+async def play(img: IMG) -> BytesIO:
     locs = [(180, 60, 100, 100), (184, 75, 100, 100), (183, 98, 100, 100),
             (179, 118, 110, 100), (156, 194, 150, 48), (178, 136, 122, 69),
             (175, 66, 122, 85), (170, 42, 130, 96), (175, 34, 118, 95),
@@ -142,7 +142,7 @@ async def play(img: IMG, *args) -> BytesIO:
     return save_gif(frames, 0.06)
 
 
-async def pat(img: IMG, *args) -> BytesIO:
+async def pat(img: IMG) -> BytesIO:
     locs = [(11, 73, 106, 100), (8, 79, 112, 96)]
     img_frames = []
     for i in range(10):
@@ -158,7 +158,7 @@ async def pat(img: IMG, *args) -> BytesIO:
     return save_gif(frames, 0.085)
 
 
-async def rip(img: IMG, *args) -> BytesIO:
+async def rip(img: IMG) -> BytesIO:
     rip = await load_resource('rip', '0.png')
     frame = Image.new('RGBA', rip.size, (255, 255, 255, 0))
     left = rotate(resize(img, (385, 385)), 24)
@@ -169,7 +169,7 @@ async def rip(img: IMG, *args) -> BytesIO:
     return save_jpg(frame)
 
 
-async def throw(img: IMG, *args) -> BytesIO:
+async def throw(img: IMG) -> BytesIO:
     img = resize(rotate(circle(img), random.randint(1, 360),
                         expand=False), (143, 143))
     frame = await load_resource('throw', '0.png')
@@ -177,14 +177,14 @@ async def throw(img: IMG, *args) -> BytesIO:
     return save_jpg(frame)
 
 
-async def crawl(img: IMG, *args) -> BytesIO:
+async def crawl(img: IMG) -> BytesIO:
     img = resize(circle(img), (100, 100))
     frame = await load_resource('crawl', '{:02d}.jpg'.format(random.randint(1, 92)))
     frame.paste(img, (0, 400), mask=img)
     return save_jpg(frame)
 
 
-async def support(img: IMG, *args) -> BytesIO:
+async def support(img: IMG) -> BytesIO:
     support = await load_resource('support', '0.png')
     frame = Image.new('RGBA', support.size, (255, 255, 255, 0))
     img = rotate(resize(img, (815, 815)), 23)
@@ -193,7 +193,7 @@ async def support(img: IMG, *args) -> BytesIO:
     return save_jpg(frame)
 
 
-async def always(img: IMG, *args) -> BytesIO:
+async def always(img: IMG) -> BytesIO:
     always = await load_resource('always', '1.png')
     w, h = img.size
     h1 = int(h / w * 300)
@@ -218,7 +218,7 @@ async def always(img: IMG, *args) -> BytesIO:
         return save_gif(frames, img.info['duration'] / 1000)
 
 
-async def loading(img: IMG, *args) -> BytesIO:
+async def loading(img: IMG) -> BytesIO:
     bg = await load_resource('loading', '0.png')
     icon = await load_resource('loading', '1.png')
     w, h = img.size
